# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bibc/core/client/v1/tx.proto\x12\x12ibc.core.client.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a$cosmos/upgrade/v1beta1/upgrade.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1fibc/core/client/v1/client.proto\"\xb2\x01\n\x0fMsgCreateClient\x12\x37\n\x0c\x63lient_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0b\x63lientState\x12=\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0e\x63onsensusState\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x19\n\x17MsgCreateClientResponse\"\x94\x01\n\x0fMsgUpdateClient\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12;\n\x0e\x63lient_message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\rclientMessage\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x19\n\x17MsgUpdateClientResponse\"\xc5\x02\n\x10MsgUpgradeClient\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x37\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0b\x63lientState\x12=\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0e\x63onsensusState\x12\x30\n\x14proof_upgrade_client\x18\x04 \x01(\x0cR\x12proofUpgradeClient\x12\x41\n\x1dproof_upgrade_consensus_state\x18\x05 \x01(\x0cR\x1aproofUpgradeConsensusState\x12\x16\n\x06signer\x18\x06 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1a\n\x18MsgUpgradeClientResponse\"\x99\x01\n\x15MsgSubmitMisbehaviour\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x38\n\x0cmisbehaviour\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0cmisbehaviour\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x11\x18\x01\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1f\n\x1dMsgSubmitMisbehaviourResponse\"\x99\x01\n\x10MsgRecoverClient\x12*\n\x11subject_client_id\x18\x01 \x01(\tR\x0fsubjectClientId\x12\x30\n\x14substitute_client_id\x18\x02 \x01(\tR\x12substituteClientId\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1a\n\x18MsgRecoverClientResponse\"\xbe\x01\n\x15MsgIBCSoftwareUpgrade\x12\x36\n\x04plan\x18\x01 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanB\x04\xc8\xde\x1f\x00R\x04plan\x12H\n\x15upgraded_client_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x13upgradedClientState\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0b\x82\xe7\xb0*\x06signer\"\x1f\n\x1dMsgIBCSoftwareUpgradeResponse\"t\n\x0fMsgUpdateParams\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x19\n\x17MsgUpdateParamsResponse2\xea\x05\n\x03Msg\x12`\n\x0c\x43reateClient\x12#.ibc.core.client.v1.MsgCreateClient\x1a+.ibc.core.client.v1.MsgCreateClientResponse\x12`\n\x0cUpdateClient\x12#.ibc.core.client.v1.MsgUpdateClient\x1a+.ibc.core.client.v1.MsgUpdateClientResponse\x12\x63\n\rUpgradeClient\x12$.ibc.core.client.v1.MsgUpgradeClient\x1a,.ibc.core.client.v1.MsgUpgradeClientResponse\x12r\n\x12SubmitMisbehaviour\x12).ibc.core.client.v1.MsgSubmitMisbehaviour\x1a\x31.ibc.core.client.v1.MsgSubmitMisbehaviourResponse\x12\x63\n\rRecoverClient\x12$.ibc.core.client.v1.MsgRecoverClient\x1a,.ibc.core.client.v1.MsgRecoverClientResponse\x12r\n\x12IBCSoftwareUpgrade\x12).ibc.core.client.v1.MsgIBCSoftwareUpgrade\x1a\x31.ibc.core.client.v1.MsgIBCSoftwareUpgradeResponse\x12\x66\n\x12UpdateClientParams\x12#.ibc.core.client.v1.MsgUpdateParams\x1a+.ibc.core.client.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xc6\x01\n\x16\x63om.ibc.core.client.v1B\x07TxProtoP\x01Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\xa2\x02\x03ICC\xaa\x02\x12Ibc.Core.Client.V1\xca\x02\x12Ibc\\Core\\Client\\V1\xe2\x02\x1eIbc\\Core\\Client\\V1\\GPBMetadata\xea\x02\x15Ibc::Core::Client::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.ibc.core.client.v1B\007TxProtoP\001Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\242\002\003ICC\252\002\022Ibc.Core.Client.V1\312\002\022Ibc\\Core\\Client\\V1\342\002\036Ibc\\Core\\Client\\V1\\GPBMetadata\352\002\025Ibc::Core::Client::V1'
  _globals['_MSGCREATECLIENT']._loaded_options = None
  _globals['_MSGCREATECLIENT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGUPDATECLIENT']._loaded_options = None
  _globals['_MSGUPDATECLIENT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGUPGRADECLIENT']._loaded_options = None
  _globals['_MSGUPGRADECLIENT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGSUBMITMISBEHAVIOUR']._loaded_options = None
  _globals['_MSGSUBMITMISBEHAVIOUR']._serialized_options = b'\030\001\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGRECOVERCLIENT']._loaded_options = None
  _globals['_MSGRECOVERCLIENT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGIBCSOFTWAREUPGRADE'].fields_by_name['plan']._loaded_options = None
  _globals['_MSGIBCSOFTWAREUPGRADE'].fields_by_name['plan']._serialized_options = b'\310\336\037\000'
  _globals['_MSGIBCSOFTWAREUPGRADE']._loaded_options = None
  _globals['_MSGIBCSOFTWAREUPGRADE']._serialized_options = b'\202\347\260*\006signer'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATECLIENT']._serialized_start=197
  _globals['_MSGCREATECLIENT']._serialized_end=375
  _globals['_MSGCREATECLIENTRESPONSE']._serialized_start=377
  _globals['_MSGCREATECLIENTRESPONSE']._serialized_end=402
  _globals['_MSGUPDATECLIENT']._serialized_start=405
  _globals['_MSGUPDATECLIENT']._serialized_end=553
  _globals['_MSGUPDATECLIENTRESPONSE']._serialized_start=555
  _globals['_MSGUPDATECLIENTRESPONSE']._serialized_end=580
  _globals['_MSGUPGRADECLIENT']._serialized_start=583
  _globals['_MSGUPGRADECLIENT']._serialized_end=908
  _globals['_MSGUPGRADECLIENTRESPONSE']._serialized_start=910
  _globals['_MSGUPGRADECLIENTRESPONSE']._serialized_end=936
  _globals['_MSGSUBMITMISBEHAVIOUR']._serialized_start=939
  _globals['_MSGSUBMITMISBEHAVIOUR']._serialized_end=1092
  _globals['_MSGSUBMITMISBEHAVIOURRESPONSE']._serialized_start=1094
  _globals['_MSGSUBMITMISBEHAVIOURRESPONSE']._serialized_end=1125
  _globals['_MSGRECOVERCLIENT']._serialized_start=1128
  _globals['_MSGRECOVERCLIENT']._serialized_end=1281
  _globals['_MSGRECOVERCLIENTRESPONSE']._serialized_start=1283
  _globals['_MSGRECOVERCLIENTRESPONSE']._serialized_end=1309
  _globals['_MSGIBCSOFTWAREUPGRADE']._serialized_start=1312
  _globals['_MSGIBCSOFTWAREUPGRADE']._serialized_end=1502
  _globals['_MSGIBCSOFTWAREUPGRADERESPONSE']._serialized_start=1504
  _globals['_MSGIBCSOFTWAREUPGRADERESPONSE']._serialized_end=1535
  _globals['_MSGUPDATEPARAMS']._serialized_start=1537
  _globals['_MSGUPDATEPARAMS']._serialized_end=1653
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1655
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1680
  _globals['_MSG']._serialized_start=1683
  _globals['_MSG']._serialized_end=2429
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/field_behavior.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgoogle/api/field_behavior.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto*\xb6\x01\n\rFieldBehavior\x12\x1e\n\x1a\x46IELD_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x0c\n\x08OPTIONAL\x10\x01\x12\x0c\n\x08REQUIRED\x10\x02\x12\x0f\n\x0bOUTPUT_ONLY\x10\x03\x12\x0e\n\nINPUT_ONLY\x10\x04\x12\r\n\tIMMUTABLE\x10\x05\x12\x12\n\x0eUNORDERED_LIST\x10\x06\x12\x15\n\x11NON_EMPTY_DEFAULT\x10\x07\x12\x0e\n\nIDENTIFIER\x10\x08:d\n\x0e\x66ield_behavior\x12\x1d.google.protobuf.FieldOptions\x18\x9c\x08 \x03(\x0e\x32\x19.google.api.FieldBehaviorB\x02\x10\x00R\rfieldBehaviorB\xb0\x01\n\x0e\x63om.google.apiB\x12\x46ieldBehaviorProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x03GAX\xaa\x02\nGoogle.Api\xca\x02\nGoogle\\Api\xe2\x02\x16Google\\Api\\GPBMetadata\xea\x02\x0bGoogle::Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.field_behavior_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\022FieldBehaviorProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\242\002\003GAX\252\002\nGoogle.Api\312\002\nGoogle\\Api\342\002\026Google\\Api\\GPBMetadata\352\002\013Google::Api'
  _globals['field_behavior']._loaded_options = None
  _globals['field_behavior']._serialized_options = b'\020\000'
  _globals['_FIELDBEHAVIOR']._serialized_start=82
  _globals['_FIELDBEHAVIOR']._serialized_end=264
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_derivative_exchange_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0exchange/injective_derivative_exchange_rpc.proto\x12!injective_derivative_exchange_rpc\"\x7f\n\x0eMarketsRequest\x12#\n\rmarket_status\x18\x01 \x01(\tR\x0cmarketStatus\x12\x1f\n\x0bquote_denom\x18\x02 \x01(\tR\nquoteDenom\x12\'\n\x0fmarket_statuses\x18\x03 \x03(\tR\x0emarketStatuses\"d\n\x0fMarketsResponse\x12Q\n\x07markets\x18\x01 \x03(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeMarketInfoR\x07markets\"\x9c\t\n\x14\x44\x65rivativeMarketInfo\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rmarket_status\x18\x02 \x01(\tR\x0cmarketStatus\x12\x16\n\x06ticker\x18\x03 \x01(\tR\x06ticker\x12\x1f\n\x0boracle_base\x18\x04 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\x05 \x01(\tR\x0boracleQuote\x12\x1f\n\x0boracle_type\x18\x06 \x01(\tR\noracleType\x12.\n\x13oracle_scale_factor\x18\x07 \x01(\rR\x11oracleScaleFactor\x12\x30\n\x14initial_margin_ratio\x18\x08 \x01(\tR\x12initialMarginRatio\x12\x38\n\x18maintenance_margin_ratio\x18\t \x01(\tR\x16maintenanceMarginRatio\x12\x1f\n\x0bquote_denom\x18\n \x01(\tR\nquoteDenom\x12V\n\x10quote_token_meta\x18\x0b \x01(\x0b\x32,.injective_derivative_exchange_rpc.TokenMetaR\x0equoteTokenMeta\x12$\n\x0emaker_fee_rate\x18\x0c \x01(\tR\x0cmakerFeeRate\x12$\n\x0etaker_fee_rate\x18\r \x01(\tR\x0ctakerFeeRate\x12\x30\n\x14service_provider_fee\x18\x0e \x01(\tR\x12serviceProviderFee\x12!\n\x0cis_perpetual\x18\x0f \x01(\x08R\x0bisPerpetual\x12-\n\x13min_price_tick_size\x18\x10 \x01(\tR\x10minPriceTickSize\x12\x33\n\x16min_quantity_tick_size\x18\x11 \x01(\tR\x13minQuantityTickSize\x12j\n\x15perpetual_market_info\x18\x12 \x01(\x0b\x32\x36.injective_derivative_exchange_rpc.PerpetualMarketInfoR\x13perpetualMarketInfo\x12s\n\x18perpetual_market_funding\x18\x13 \x01(\x0b\x32\x39.injective_derivative_exchange_rpc.PerpetualMarketFundingR\x16perpetualMarketFunding\x12w\n\x1a\x65xpiry_futures_market_info\x18\x14 \x01(\x0b\x32:.injective_derivative_exchange_rpc.ExpiryFuturesMarketInfoR\x17\x65xpiryFuturesMarketInfo\x12!\n\x0cmin_notional\x18\x15 \x01(\tR\x0bminNotional\x12.\n\x13reduce_margin_ratio\x18\x16 \x01(\tR\x11reduceMarginRatio\"\xa0\x01\n\tTokenMeta\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06symbol\x18\x03 \x01(\tR\x06symbol\x12\x12\n\x04logo\x18\x04 \x01(\tR\x04logo\x12\x1a\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11R\x08\x64\x65\x63imals\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\"\xdf\x01\n\x13PerpetualMarketInfo\x12\x35\n\x17hourly_funding_rate_cap\x18\x01 \x01(\tR\x14hourlyFundingRateCap\x12\x30\n\x14hourly_interest_rate\x18\x02 \x01(\tR\x12hourlyInterestRate\x12\x34\n\x16next_funding_timestamp\x18\x03 \x01(\x12R\x14nextFundingTimestamp\x12)\n\x10\x66unding_interval\x18\x04 \x01(\x12R\x0f\x66undingInterval\"\xc5\x01\n\x16PerpetualMarketFunding\x12-\n\x12\x63umulative_funding\x18\x01 \x01(\tR\x11\x63umulativeFunding\x12)\n\x10\x63umulative_price\x18\x02 \x01(\tR\x0f\x63umulativePrice\x12%\n\x0elast_timestamp\x18\x03 \x01(\x12R\rlastTimestamp\x12*\n\x11last_funding_rate\x18\x04 \x01(\tR\x0flastFundingRate\"w\n\x17\x45xpiryFuturesMarketInfo\x12\x31\n\x14\x65xpiration_timestamp\x18\x01 \x01(\x12R\x13\x65xpirationTimestamp\x12)\n\x10settlement_price\x18\x02 \x01(\tR\x0fsettlementPrice\",\n\rMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"a\n\x0eMarketResponse\x12O\n\x06market\x18\x01 \x01(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeMarketInfoR\x06market\"4\n\x13StreamMarketRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"\xac\x01\n\x14StreamMarketResponse\x12O\n\x06market\x18\x01 \x01(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeMarketInfoR\x06market\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\x8d\x01\n\x1b\x42inaryOptionsMarketsRequest\x12#\n\rmarket_status\x18\x01 \x01(\tR\x0cmarketStatus\x12\x1f\n\x0bquote_denom\x18\x02 \x01(\tR\nquoteDenom\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\"\xb7\x01\n\x1c\x42inaryOptionsMarketsResponse\x12T\n\x07markets\x18\x01 \x03(\x0b\x32:.injective_derivative_exchange_rpc.BinaryOptionsMarketInfoR\x07markets\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xa1\x06\n\x17\x42inaryOptionsMarketInfo\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rmarket_status\x18\x02 \x01(\tR\x0cmarketStatus\x12\x16\n\x06ticker\x18\x03 \x01(\tR\x06ticker\x12#\n\roracle_symbol\x18\x04 \x01(\tR\x0coracleSymbol\x12\'\n\x0foracle_provider\x18\x05 \x01(\tR\x0eoracleProvider\x12\x1f\n\x0boracle_type\x18\x06 \x01(\tR\noracleType\x12.\n\x13oracle_scale_factor\x18\x07 \x01(\rR\x11oracleScaleFactor\x12\x31\n\x14\x65xpiration_timestamp\x18\x08 \x01(\x12R\x13\x65xpirationTimestamp\x12\x31\n\x14settlement_timestamp\x18\t \x01(\x12R\x13settlementTimestamp\x12\x1f\n\x0bquote_denom\x18\n \x01(\tR\nquoteDenom\x12V\n\x10quote_token_meta\x18\x0b \x01(\x0b\x32,.injective_derivative_exchange_rpc.TokenMetaR\x0equoteTokenMeta\x12$\n\x0emaker_fee_rate\x18\x0c \x01(\tR\x0cmakerFeeRate\x12$\n\x0etaker_fee_rate\x18\r \x01(\tR\x0ctakerFeeRate\x12\x30\n\x14service_provider_fee\x18\x0e \x01(\tR\x12serviceProviderFee\x12-\n\x13min_price_tick_size\x18\x0f \x01(\tR\x10minPriceTickSize\x12\x33\n\x16min_quantity_tick_size\x18\x10 \x01(\tR\x13minQuantityTickSize\x12)\n\x10settlement_price\x18\x11 \x01(\tR\x0fsettlementPrice\x12!\n\x0cmin_notional\x18\x12 \x01(\tR\x0bminNotional\"\x86\x01\n\x06Paging\x12\x14\n\x05total\x18\x01 \x01(\x12R\x05total\x12\x12\n\x04\x66rom\x18\x02 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x03 \x01(\x11R\x02to\x12.\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12R\x11\x63ountBySubaccount\x12\x12\n\x04next\x18\x05 \x03(\tR\x04next\"9\n\x1a\x42inaryOptionsMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"q\n\x1b\x42inaryOptionsMarketResponse\x12R\n\x06market\x18\x01 \x01(\x0b\x32:.injective_derivative_exchange_rpc.BinaryOptionsMarketInfoR\x06market\"G\n\x12OrderbookV2Request\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x14\n\x05\x64\x65pth\x18\x02 \x01(\x11R\x05\x64\x65pth\"r\n\x13OrderbookV2Response\x12[\n\torderbook\x18\x01 \x01(\x0b\x32=.injective_derivative_exchange_rpc.DerivativeLimitOrderbookV2R\torderbook\"\xde\x01\n\x1a\x44\x65rivativeLimitOrderbookV2\x12\x41\n\x04\x62uys\x18\x01 \x03(\x0b\x32-.injective_derivative_exchange_rpc.PriceLevelR\x04\x62uys\x12\x43\n\x05sells\x18\x02 \x03(\x0b\x32-.injective_derivative_exchange_rpc.PriceLevelR\x05sells\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\\\n\nPriceLevel\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\tR\x08quantity\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"J\n\x13OrderbooksV2Request\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\x12\x14\n\x05\x64\x65pth\x18\x02 \x01(\x11R\x05\x64\x65pth\"{\n\x14OrderbooksV2Response\x12\x63\n\norderbooks\x18\x01 \x03(\x0b\x32\x43.injective_derivative_exchange_rpc.SingleDerivativeLimitOrderbookV2R\norderbooks\"\x9c\x01\n SingleDerivativeLimitOrderbookV2\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12[\n\torderbook\x18\x02 \x01(\x0b\x32=.injective_derivative_exchange_rpc.DerivativeLimitOrderbookV2R\torderbook\"9\n\x18StreamOrderbookV2Request\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"\xda\x01\n\x19StreamOrderbookV2Response\x12[\n\torderbook\x18\x01 \x01(\x0b\x32=.injective_derivative_exchange_rpc.DerivativeLimitOrderbookV2R\torderbook\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\x12\x1b\n\tmarket_id\x18\x04 \x01(\tR\x08marketId\"=\n\x1cStreamOrderbookUpdateRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"\xf3\x01\n\x1dStreamOrderbookUpdateResponse\x12p\n\x17orderbook_level_updates\x18\x01 \x01(\x0b\x32\x38.injective_derivative_exchange_rpc.OrderbookLevelUpdatesR\x15orderbookLevelUpdates\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\x12\x1b\n\tmarket_id\x18\x04 \x01(\tR\x08marketId\"\x83\x02\n\x15OrderbookLevelUpdates\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12G\n\x04\x62uys\x18\x03 \x03(\x0b\x32\x33.injective_derivative_exchange_rpc.PriceLevelUpdateR\x04\x62uys\x12I\n\x05sells\x18\x04 \x03(\x0b\x32\x33.injective_derivative_exchange_rpc.PriceLevelUpdateR\x05sells\x12\x1d\n\nupdated_at\x18\x05 \x01(\x12R\tupdatedAt\"\x7f\n\x10PriceLevelUpdate\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\tR\x08quantity\x12\x1b\n\tis_active\x18\x03 \x01(\x08R\x08isActive\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\xc9\x03\n\rOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x04 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x05 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x06 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x07 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\x08 \x03(\tR\tmarketIds\x12%\n\x0eis_conditional\x18\t \x01(\tR\risConditional\x12\x1d\n\norder_type\x18\n \x01(\tR\torderType\x12)\n\x10include_inactive\x18\x0b \x01(\x08R\x0fincludeInactive\x12\x36\n\x17subaccount_total_orders\x18\x0c \x01(\x08R\x15subaccountTotalOrders\x12\x19\n\x08trade_id\x18\r \x01(\tR\x07tradeId\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\"\xa4\x01\n\x0eOrdersResponse\x12O\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeLimitOrderR\x06orders\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xd7\x05\n\x14\x44\x65rivativeLimitOrder\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12$\n\x0eis_reduce_only\x18\x05 \x01(\x08R\x0cisReduceOnly\x12\x16\n\x06margin\x18\x06 \x01(\tR\x06margin\x12\x14\n\x05price\x18\x07 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x08 \x01(\tR\x08quantity\x12+\n\x11unfilled_quantity\x18\t \x01(\tR\x10unfilledQuantity\x12#\n\rtrigger_price\x18\n \x01(\tR\x0ctriggerPrice\x12#\n\rfee_recipient\x18\x0b \x01(\tR\x0c\x66\x65\x65Recipient\x12\x14\n\x05state\x18\x0c \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\r \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0e \x01(\x12R\tupdatedAt\x12!\n\x0corder_number\x18\x0f \x01(\x12R\x0borderNumber\x12\x1d\n\norder_type\x18\x10 \x01(\tR\torderType\x12%\n\x0eis_conditional\x18\x11 \x01(\x08R\risConditional\x12\x1d\n\ntrigger_at\x18\x12 \x01(\x04R\ttriggerAt\x12*\n\x11placed_order_hash\x18\x13 \x01(\tR\x0fplacedOrderHash\x12%\n\x0e\x65xecution_type\x18\x14 \x01(\tR\rexecutionType\x12\x17\n\x07tx_hash\x18\x15 \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x16 \x01(\tR\x03\x63id\"\xdc\x02\n\x10PositionsRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x05 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x06 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\x07 \x03(\tR\tmarketIds\x12\x1c\n\tdirection\x18\x08 \x01(\tR\tdirection\x12<\n\x1asubaccount_total_positions\x18\t \x01(\x08R\x18subaccountTotalPositions\x12\'\n\x0f\x61\x63\x63ount_address\x18\n \x01(\tR\x0e\x61\x63\x63ountAddress\"\xab\x01\n\x11PositionsResponse\x12S\n\tpositions\x18\x01 \x03(\x0b\x32\x35.injective_derivative_exchange_rpc.DerivativePositionR\tpositions\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xb0\x03\n\x12\x44\x65rivativePosition\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0b\x65ntry_price\x18\x06 \x01(\tR\nentryPrice\x12\x16\n\x06margin\x18\x07 \x01(\tR\x06margin\x12+\n\x11liquidation_price\x18\x08 \x01(\tR\x10liquidationPrice\x12\x1d\n\nmark_price\x18\t \x01(\tR\tmarkPrice\x12\x43\n\x1e\x61ggregate_reduce_only_quantity\x18\x0b \x01(\tR\x1b\x61ggregateReduceOnlyQuantity\x12\x1d\n\nupdated_at\x18\x0c \x01(\x12R\tupdatedAt\x12\x1d\n\ncreated_at\x18\r \x01(\x12R\tcreatedAt\"\xde\x02\n\x12PositionsV2Request\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x05 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x06 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\x07 \x03(\tR\tmarketIds\x12\x1c\n\tdirection\x18\x08 \x01(\tR\tdirection\x12<\n\x1asubaccount_total_positions\x18\t \x01(\x08R\x18subaccountTotalPositions\x12\'\n\x0f\x61\x63\x63ount_address\x18\n \x01(\tR\x0e\x61\x63\x63ountAddress\"\xaf\x01\n\x13PositionsV2Response\x12U\n\tpositions\x18\x01 \x03(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativePositionV2R\tpositions\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xe4\x02\n\x14\x44\x65rivativePositionV2\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0b\x65ntry_price\x18\x06 \x01(\tR\nentryPrice\x12\x16\n\x06margin\x18\x07 \x01(\tR\x06margin\x12+\n\x11liquidation_price\x18\x08 \x01(\tR\x10liquidationPrice\x12\x1d\n\nmark_price\x18\t \x01(\tR\tmarkPrice\x12\x1d\n\nupdated_at\x18\x0b \x01(\x12R\tupdatedAt\x12\x14\n\x05\x64\x65nom\x18\x0c \x01(\tR\x05\x64\x65nom\"c\n\x1aLiquidablePositionsRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x02 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\"r\n\x1bLiquidablePositionsResponse\x12S\n\tpositions\x18\x01 \x03(\x0b\x32\x35.injective_derivative_exchange_rpc.DerivativePositionR\tpositions\"\xbe\x01\n\x16\x46undingPaymentsRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\x12\x19\n\x08\x65nd_time\x18\x05 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\x06 \x03(\tR\tmarketIds\"\xab\x01\n\x17\x46undingPaymentsResponse\x12M\n\x08payments\x18\x01 \x03(\x0b\x32\x31.injective_derivative_exchange_rpc.FundingPaymentR\x08payments\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\x88\x01\n\x0e\x46undingPayment\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x16\n\x06\x61mount\x18\x03 \x01(\tR\x06\x61mount\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"w\n\x13\x46undingRatesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x02 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\x12\x19\n\x08\x65nd_time\x18\x04 \x01(\x12R\x07\x65ndTime\"\xae\x01\n\x14\x46undingRatesResponse\x12S\n\rfunding_rates\x18\x01 \x03(\x0b\x32..injective_derivative_exchange_rpc.FundingRateR\x0c\x66undingRates\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\\\n\x0b\x46undingRate\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x12\n\x04rate\x18\x02 \x01(\tR\x04rate\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\xc9\x01\n\x16StreamPositionsRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1d\n\nmarket_ids\x18\x03 \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\x04 \x03(\tR\rsubaccountIds\x12\'\n\x0f\x61\x63\x63ount_address\x18\x05 \x01(\tR\x0e\x61\x63\x63ountAddress\"\x8a\x01\n\x17StreamPositionsResponse\x12Q\n\x08position\x18\x01 \x01(\x0b\x32\x35.injective_derivative_exchange_rpc.DerivativePositionR\x08position\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\"\xcb\x01\n\x18StreamPositionsV2Request\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1d\n\nmarket_ids\x18\x03 \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\x04 \x03(\tR\rsubaccountIds\x12\'\n\x0f\x61\x63\x63ount_address\x18\x05 \x01(\tR\x0e\x61\x63\x63ountAddress\"\x8e\x01\n\x19StreamPositionsV2Response\x12S\n\x08position\x18\x01 \x01(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativePositionV2R\x08position\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\"\xcf\x03\n\x13StreamOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x04 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x05 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x06 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x07 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\x08 \x03(\tR\tmarketIds\x12%\n\x0eis_conditional\x18\t \x01(\tR\risConditional\x12\x1d\n\norder_type\x18\n \x01(\tR\torderType\x12)\n\x10include_inactive\x18\x0b \x01(\x08R\x0fincludeInactive\x12\x36\n\x17subaccount_total_orders\x18\x0c \x01(\x08R\x15subaccountTotalOrders\x12\x19\n\x08trade_id\x18\r \x01(\tR\x07tradeId\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\"\xaa\x01\n\x14StreamOrdersResponse\x12M\n\x05order\x18\x01 \x01(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeLimitOrderR\x05order\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\xe4\x03\n\rTradesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\x9f\x01\n\x0eTradesResponse\x12J\n\x06trades\x18\x01 \x03(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTradeR\x06trades\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xfa\x03\n\x0f\x44\x65rivativeTrade\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x30\n\x14trade_execution_type\x18\x04 \x01(\tR\x12tradeExecutionType\x12%\n\x0eis_liquidation\x18\x05 \x01(\x08R\risLiquidation\x12W\n\x0eposition_delta\x18\x06 \x01(\x0b\x32\x30.injective_derivative_exchange_rpc.PositionDeltaR\rpositionDelta\x12\x16\n\x06payout\x18\x07 \x01(\tR\x06payout\x12\x10\n\x03\x66\x65\x65\x18\x08 \x01(\tR\x03\x66\x65\x65\x12\x1f\n\x0b\x65xecuted_at\x18\t \x01(\x12R\nexecutedAt\x12#\n\rfee_recipient\x18\n \x01(\tR\x0c\x66\x65\x65Recipient\x12\x19\n\x08trade_id\x18\x0b \x01(\tR\x07tradeId\x12%\n\x0e\x65xecution_side\x18\x0c \x01(\tR\rexecutionSide\x12\x10\n\x03\x63id\x18\r \x01(\tR\x03\x63id\x12\x10\n\x03pnl\x18\x0e \x01(\tR\x03pnl\"\xbb\x01\n\rPositionDelta\x12\'\n\x0ftrade_direction\x18\x01 \x01(\tR\x0etradeDirection\x12\'\n\x0f\x65xecution_price\x18\x02 \x01(\tR\x0e\x65xecutionPrice\x12-\n\x12\x65xecution_quantity\x18\x03 \x01(\tR\x11\x65xecutionQuantity\x12)\n\x10\x65xecution_margin\x18\x04 \x01(\tR\x0f\x65xecutionMargin\"\xe6\x03\n\x0fTradesV2Request\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\xa1\x01\n\x10TradesV2Response\x12J\n\x06trades\x18\x01 \x03(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTradeR\x06trades\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xea\x03\n\x13StreamTradesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\xa5\x01\n\x14StreamTradesResponse\x12H\n\x05trade\x18\x01 \x01(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTradeR\x05trade\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\xec\x03\n\x15StreamTradesV2Request\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_side\x18\x02 \x01(\tR\rexecutionSide\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12\x1d\n\nmarket_ids\x18\t \x03(\tR\tmarketIds\x12%\n\x0esubaccount_ids\x18\n \x03(\tR\rsubaccountIds\x12\'\n\x0f\x65xecution_types\x18\x0b \x03(\tR\x0e\x65xecutionTypes\x12\x19\n\x08trade_id\x18\x0c \x01(\tR\x07tradeId\x12\'\n\x0f\x61\x63\x63ount_address\x18\r \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\x12#\n\rfee_recipient\x18\x0f \x01(\tR\x0c\x66\x65\x65Recipient\"\xa7\x01\n\x16StreamTradesV2Response\x12H\n\x05trade\x18\x01 \x01(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTradeR\x05trade\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\x89\x01\n\x1bSubaccountOrdersListRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\"\xb2\x01\n\x1cSubaccountOrdersListResponse\x12O\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective_derivative_exchange_rpc.DerivativeLimitOrderR\x06orders\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xce\x01\n\x1bSubaccountTradesListRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12%\n\x0e\x65xecution_type\x18\x03 \x01(\tR\rexecutionType\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x06 \x01(\x11R\x05limit\"j\n\x1cSubaccountTradesListResponse\x12J\n\x06trades\x18\x01 \x03(\x0b\x32\x32.injective_derivative_exchange_rpc.DerivativeTradeR\x06trades\"\xfc\x03\n\x14OrdersHistoryRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x12\n\x04skip\x18\x03 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\x12\x1f\n\x0border_types\x18\x05 \x03(\tR\norderTypes\x12\x1c\n\tdirection\x18\x06 \x01(\tR\tdirection\x12\x1d\n\nstart_time\x18\x07 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x12R\x07\x65ndTime\x12%\n\x0eis_conditional\x18\t \x01(\tR\risConditional\x12\x1d\n\norder_type\x18\n \x01(\tR\torderType\x12\x14\n\x05state\x18\x0b \x01(\tR\x05state\x12\'\n\x0f\x65xecution_types\x18\x0c \x03(\tR\x0e\x65xecutionTypes\x12\x1d\n\nmarket_ids\x18\r \x03(\tR\tmarketIds\x12\x19\n\x08trade_id\x18\x0e \x01(\tR\x07tradeId\x12.\n\x13\x61\x63tive_markets_only\x18\x0f \x01(\x08R\x11\x61\x63tiveMarketsOnly\x12\x10\n\x03\x63id\x18\x10 \x01(\tR\x03\x63id\"\xad\x01\n\x15OrdersHistoryResponse\x12Q\n\x06orders\x18\x01 \x03(\x0b\x32\x39.injective_derivative_exchange_rpc.DerivativeOrderHistoryR\x06orders\x12\x41\n\x06paging\x18\x02 \x01(\x0b\x32).injective_derivative_exchange_rpc.PagingR\x06paging\"\xa9\x05\n\x16\x44\x65rivativeOrderHistory\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1b\n\tis_active\x18\x03 \x01(\x08R\x08isActive\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12%\n\x0e\x65xecution_type\x18\x05 \x01(\tR\rexecutionType\x12\x1d\n\norder_type\x18\x06 \x01(\tR\torderType\x12\x14\n\x05price\x18\x07 \x01(\tR\x05price\x12#\n\rtrigger_price\x18\x08 \x01(\tR\x0ctriggerPrice\x12\x1a\n\x08quantity\x18\t \x01(\tR\x08quantity\x12\'\n\x0f\x66illed_quantity\x18\n \x01(\tR\x0e\x66illedQuantity\x12\x14\n\x05state\x18\x0b \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\r \x01(\x12R\tupdatedAt\x12$\n\x0eis_reduce_only\x18\x0e \x01(\x08R\x0cisReduceOnly\x12\x1c\n\tdirection\x18\x0f \x01(\tR\tdirection\x12%\n\x0eis_conditional\x18\x10 \x01(\x08R\risConditional\x12\x1d\n\ntrigger_at\x18\x11 \x01(\x04R\ttriggerAt\x12*\n\x11placed_order_hash\x18\x12 \x01(\tR\x0fplacedOrderHash\x12\x16\n\x06margin\x18\x13 \x01(\tR\x06margin\x12\x17\n\x07tx_hash\x18\x14 \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x15 \x01(\tR\x03\x63id\"\xdc\x01\n\x1aStreamOrdersHistoryRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1f\n\x0border_types\x18\x03 \x03(\tR\norderTypes\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x14\n\x05state\x18\x05 \x01(\tR\x05state\x12\'\n\x0f\x65xecution_types\x18\x06 \x03(\tR\x0e\x65xecutionTypes\"\xb3\x01\n\x1bStreamOrdersHistoryResponse\x12O\n\x05order\x18\x01 \x01(\x0b\x32\x39.injective_derivative_exchange_rpc.DerivativeOrderHistoryR\x05order\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"5\n\x13OpenInterestRequest\x12\x1e\n\x0bmarket_i_ds\x18\x01 \x03(\tR\tmarketIDs\"t\n\x14OpenInterestResponse\x12\\\n\x0eopen_interests\x18\x01 \x03(\x0b\x32\x35.injective_derivative_exchange_rpc.MarketOpenInterestR\ropenInterests\"V\n\x12MarketOpenInterest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\ropen_interest\x18\x02 \x01(\tR\x0copenInterest2\xd8\x1c\n\x1eInjectiveDerivativeExchangeRPC\x12p\n\x07Markets\x12\x31.injective_derivative_exchange_rpc.MarketsRequest\x1a\x32.injective_derivative_exchange_rpc.MarketsResponse\x12m\n\x06Market\x12\x30.injective_derivative_exchange_rpc.MarketRequest\x1a\x31.injective_derivative_exchange_rpc.MarketResponse\x12\x81\x01\n\x0cStreamMarket\x12\x36.injective_derivative_exchange_rpc.StreamMarketRequest\x1a\x37.injective_derivative_exchange_rpc.StreamMarketResponse0\x01\x12\x97\x01\n\x14\x42inaryOptionsMarkets\x12>.injective_derivative_exchange_rpc.BinaryOptionsMarketsRequest\x1a?.injective_derivative_exchange_rpc.BinaryOptionsMarketsResponse\x12\x94\x01\n\x13\x42inaryOptionsMarket\x12=.injective_derivative_exchange_rpc.BinaryOptionsMarketRequest\x1a>.injective_derivative_exchange_rpc.BinaryOptionsMarketResponse\x12|\n\x0bOrderbookV2\x12\x35.injective_derivative_exchange_rpc.OrderbookV2Request\x1a\x36.injective_derivative_exchange_rpc.OrderbookV2Response\x12\x7f\n\x0cOrderbooksV2\x12\x36.injective_derivative_exchange_rpc.OrderbooksV2Request\x1a\x37.injective_derivative_exchange_rpc.OrderbooksV2Response\x12\x90\x01\n\x11StreamOrderbookV2\x12;.injective_derivative_exchange_rpc.StreamOrderbookV2Request\x1a<.injective_derivative_exchange_rpc.StreamOrderbookV2Response0\x01\x12\x9c\x01\n\x15StreamOrderbookUpdate\x12?.injective_derivative_exchange_rpc.StreamOrderbookUpdateRequest\x1a@.injective_derivative_exchange_rpc.StreamOrderbookUpdateResponse0\x01\x12m\n\x06Orders\x12\x30.injective_derivative_exchange_rpc.OrdersRequest\x1a\x31.injective_derivative_exchange_rpc.OrdersResponse\x12v\n\tPositions\x12\x33.injective_derivative_exchange_rpc.PositionsRequest\x1a\x34.injective_derivative_exchange_rpc.PositionsResponse\x12|\n\x0bPositionsV2\x12\x35.injective_derivative_exchange_rpc.PositionsV2Request\x1a\x36.injective_derivative_exchange_rpc.PositionsV2Response\x12\x94\x01\n\x13LiquidablePositions\x12=.injective_derivative_exchange_rpc.LiquidablePositionsRequest\x1a>.injective_derivative_exchange_rpc.LiquidablePositionsResponse\x12\x88\x01\n\x0f\x46undingPayments\x12\x39.injective_derivative_exchange_rpc.FundingPaymentsRequest\x1a:.injective_derivative_exchange_rpc.FundingPaymentsResponse\x12\x7f\n\x0c\x46undingRates\x12\x36.injective_derivative_exchange_rpc.FundingRatesRequest\x1a\x37.injective_derivative_exchange_rpc.FundingRatesResponse\x12\x8a\x01\n\x0fStreamPositions\x12\x39.injective_derivative_exchange_rpc.StreamPositionsRequest\x1a:.injective_derivative_exchange_rpc.StreamPositionsResponse0\x01\x12\x90\x01\n\x11StreamPositionsV2\x12;.injective_derivative_exchange_rpc.StreamPositionsV2Request\x1a<.injective_derivative_exchange_rpc.StreamPositionsV2Response0\x01\x12\x81\x01\n\x0cStreamOrders\x12\x36.injective_derivative_exchange_rpc.StreamOrdersRequest\x1a\x37.injective_derivative_exchange_rpc.StreamOrdersResponse0\x01\x12m\n\x06Trades\x12\x30.injective_derivative_exchange_rpc.TradesRequest\x1a\x31.injective_derivative_exchange_rpc.TradesResponse\x12s\n\x08TradesV2\x12\x32.injective_derivative_exchange_rpc.TradesV2Request\x1a\x33.injective_derivative_exchange_rpc.TradesV2Response\x12\x81\x01\n\x0cStreamTrades\x12\x36.injective_derivative_exchange_rpc.StreamTradesRequest\x1a\x37.injective_derivative_exchange_rpc.StreamTradesResponse0\x01\x12\x87\x01\n\x0eStreamTradesV2\x12\x38.injective_derivative_exchange_rpc.StreamTradesV2Request\x1a\x39.injective_derivative_exchange_rpc.StreamTradesV2Response0\x01\x12\x97\x01\n\x14SubaccountOrdersList\x12>.injective_derivative_exchange_rpc.SubaccountOrdersListRequest\x1a?.injective_derivative_exchange_rpc.SubaccountOrdersListResponse\x12\x97\x01\n\x14SubaccountTradesList\x12>.injective_derivative_exchange_rpc.SubaccountTradesListRequest\x1a?.injective_derivative_exchange_rpc.SubaccountTradesListResponse\x12\x82\x01\n\rOrdersHistory\x12\x37.injective_derivative_exchange_rpc.OrdersHistoryRequest\x1a\x38.injective_derivative_exchange_rpc.OrdersHistoryResponse\x12\x96\x01\n\x13StreamOrdersHistory\x12=.injective_derivative_exchange_rpc.StreamOrdersHistoryRequest\x1a>.injective_derivative_exchange_rpc.StreamOrdersHistoryResponse0\x01\x12\x7f\n\x0cOpenInterest\x12\x36.injective_derivative_exchange_rpc.OpenInterestRequest\x1a\x37.injective_derivative_exchange_rpc.OpenInterestResponseB\x8a\x02\n%com.injective_derivative_exchange_rpcB#InjectiveDerivativeExchangeRpcProtoP\x01Z$/injective_derivative_exchange_rpcpb\xa2\x02\x03IXX\xaa\x02\x1eInjectiveDerivativeExchangeRpc\xca\x02\x1eInjectiveDerivativeExchangeRpc\xe2\x02*InjectiveDerivativeExchangeRpc\\GPBMetadata\xea\x02\x1eInjectiveDerivativeExchangeRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_derivative_exchange_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.injective_derivative_exchange_rpcB#InjectiveDerivativeExchangeRpcProtoP\001Z$/injective_derivative_exchange_rpcpb\242\002\003IXX\252\002\036InjectiveDerivativeExchangeRpc\312\002\036InjectiveDerivativeExchangeRpc\342\002*InjectiveDerivativeExchangeRpc\\GPBMetadata\352\002\036InjectiveDerivativeExchangeRpc'
  _globals['_MARKETSREQUEST']._serialized_start=87
  _globals['_MARKETSREQUEST']._serialized_end=214
  _globals['_MARKETSRESPONSE']._serialized_start=216
  _globals['_MARKETSRESPONSE']._serialized_end=316
  _globals['_DERIVATIVEMARKETINFO']._serialized_start=319
  _globals['_DERIVATIVEMARKETINFO']._serialized_end=1499
  _globals['_TOKENMETA']._serialized_start=1502
  _globals['_TOKENMETA']._serialized_end=1662
  _globals['_PERPETUALMARKETINFO']._serialized_start=1665
  _globals['_PERPETUALMARKETINFO']._serialized_end=1888
  _globals['_PERPETUALMARKETFUNDING']._serialized_start=1891
  _globals['_PERPETUALMARKETFUNDING']._serialized_end=2088
  _globals['_EXPIRYFUTURESMARKETINFO']._serialized_start=2090
  _globals['_EXPIRYFUTURESMARKETINFO']._serialized_end=2209
  _globals['_MARKETREQUEST']._serialized_start=2211
  _globals['_MARKETREQUEST']._serialized_end=2255
  _globals['_MARKETRESPONSE']._serialized_start=2257
  _globals['_MARKETRESPONSE']._serialized_end=2354
  _globals['_STREAMMARKETREQUEST']._serialized_start=2356
  _globals['_STREAMMARKETREQUEST']._serialized_end=2408
  _globals['_STREAMMARKETRESPONSE']._serialized_start=2411
  _globals['_STREAMMARKETRESPONSE']._serialized_end=2583
  _globals['_BINARYOPTIONSMARKETSREQUEST']._serialized_start=2586
  _globals['_BINARYOPTIONSMARKETSREQUEST']._serialized_end=2727
  _globals['_BINARYOPTIONSMARKETSRESPONSE']._serialized_start=2730
  _globals['_BINARYOPTIONSMARKETSRESPONSE']._serialized_end=2913
  _globals['_BINARYOPTIONSMARKETINFO']._serialized_start=2916
  _globals['_BINARYOPTIONSMARKETINFO']._serialized_end=3717
  _globals['_PAGING']._serialized_start=3720
  _globals['_PAGING']._serialized_end=3854
  _globals['_BINARYOPTIONSMARKETREQUEST']._serialized_start=3856
  _globals['_BINARYOPTIONSMARKETREQUEST']._serialized_end=3913
  _globals['_BINARYOPTIONSMARKETRESPONSE']._serialized_start=3915
  _globals['_BINARYOPTIONSMARKETRESPONSE']._serialized_end=4028
  _globals['_ORDERBOOKV2REQUEST']._serialized_start=4030
  _globals['_ORDERBOOKV2REQUEST']._serialized_end=4101
  _globals['_ORDERBOOKV2RESPONSE']._serialized_start=4103
  _globals['_ORDERBOOKV2RESPONSE']._serialized_end=4217
  _globals['_DERIVATIVELIMITORDERBOOKV2']._serialized_start=4220
  _globals['_DERIVATIVELIMITORDERBOOKV2']._serialized_end=4442
  _globals['_PRICELEVEL']._serialized_start=4444
  _globals['_PRICELEVEL']._serialized_end=4536
  _globals['_ORDERBOOKSV2REQUEST']._serialized_start=4538
  _globals['_ORDERBOOKSV2REQUEST']._serialized_end=4612
  _globals['_ORDERBOOKSV2RESPONSE']._serialized_start=4614
  _globals['_ORDERBOOKSV2RESPONSE']._serialized_end=4737
  _globals['_SINGLEDERIVATIVELIMITORDERBOOKV2']._serialized_start=4740
  _globals['_SINGLEDERIVATIVELIMITORDERBOOKV2']._serialized_end=4896
  _globals['_STREAMORDERBOOKV2REQUEST']._serialized_start=4898
  _globals['_STREAMORDERBOOKV2REQUEST']._serialized_end=4955
  _globals['_STREAMORDERBOOKV2RESPONSE']._serialized_start=4958
  _globals['_STREAMORDERBOOKV2RESPONSE']._serialized_end=5176
  _globals['_STREAMORDERBOOKUPDATEREQUEST']._serialized_start=5178
  _globals['_STREAMORDERBOOKUPDATEREQUEST']._serialized_end=5239
  _globals['_STREAMORDERBOOKUPDATERESPONSE']._serialized_start=5242
  _globals['_STREAMORDERBOOKUPDATERESPONSE']._serialized_end=5485
  _globals['_ORDERBOOKLEVELUPDATES']._serialized_start=5488
  _globals['_ORDERBOOKLEVELUPDATES']._serialized_end=5747
  _globals['_PRICELEVELUPDATE']._serialized_start=5749
  _globals['_PRICELEVELUPDATE']._serialized_end=5876
  _globals['_ORDERSREQUEST']._serialized_start=5879
  _globals['_ORDERSREQUEST']._serialized_end=6336
  _globals['_ORDERSRESPONSE']._serialized_start=6339
  _globals['_ORDERSRESPONSE']._serialized_end=6503
  _globals['_DERIVATIVELIMITORDER']._serialized_start=6506
  _globals['_DERIVATIVELIMITORDER']._serialized_end=7233
  _globals['_POSITIONSREQUEST']._serialized_start=7236
  _globals['_POSITIONSREQUEST']._serialized_end=7584
  _globals['_POSITIONSRESPONSE']._serialized_start=7587
  _globals['_POSITIONSRESPONSE']._serialized_end=7758
  _globals['_DERIVATIVEPOSITION']._serialized_start=7761
  _globals['_DERIVATIVEPOSITION']._serialized_end=8193
  _globals['_POSITIONSV2REQUEST']._serialized_start=8196
  _globals['_POSITIONSV2REQUEST']._serialized_end=8546
  _globals['_POSITIONSV2RESPONSE']._serialized_start=8549
  _globals['_POSITIONSV2RESPONSE']._serialized_end=8724
  _globals['_DERIVATIVEPOSITIONV2']._serialized_start=8727
  _globals['_DERIVATIVEPOSITIONV2']._serialized_end=9083
  _globals['_LIQUIDABLEPOSITIONSREQUEST']._serialized_start=9085
  _globals['_LIQUIDABLEPOSITIONSREQUEST']._serialized_end=9184
  _globals['_LIQUIDABLEPOSITIONSRESPONSE']._serialized_start=9186
  _globals['_LIQUIDABLEPOSITIONSRESPONSE']._serialized_end=9300
  _globals['_FUNDINGPAYMENTSREQUEST']._serialized_start=9303
  _globals['_FUNDINGPAYMENTSREQUEST']._serialized_end=9493
  _globals['_FUNDINGPAYMENTSRESPONSE']._serialized_start=9496
  _globals['_FUNDINGPAYMENTSRESPONSE']._serialized_end=9667
  _globals['_FUNDINGPAYMENT']._serialized_start=9670
  _globals['_FUNDINGPAYMENT']._serialized_end=9806
  _globals['_FUNDINGRATESREQUEST']._serialized_start=9808
  _globals['_FUNDINGRATESREQUEST']._serialized_end=9927
  _globals['_FUNDINGRATESRESPONSE']._serialized_start=9930
  _globals['_FUNDINGRATESRESPONSE']._serialized_end=10104
  _globals['_FUNDINGRATE']._serialized_start=10106
  _globals['_FUNDINGRATE']._serialized_end=10198
  _globals['_STREAMPOSITIONSREQUEST']._serialized_start=10201
  _globals['_STREAMPOSITIONSREQUEST']._serialized_end=10402
  _globals['_STREAMPOSITIONSRESPONSE']._serialized_start=10405
  _globals['_STREAMPOSITIONSRESPONSE']._serialized_end=10543
  _globals['_STREAMPOSITIONSV2REQUEST']._serialized_start=10546
  _globals['_STREAMPOSITIONSV2REQUEST']._serialized_end=10749
  _globals['_STREAMPOSITIONSV2RESPONSE']._serialized_start=10752
  _globals['_STREAMPOSITIONSV2RESPONSE']._serialized_end=10894
  _globals['_STREAMORDERSREQUEST']._serialized_start=10897
  _globals['_STREAMORDERSREQUEST']._serialized_end=11360
  _globals['_STREAMORDERSRESPONSE']._serialized_start=11363
  _globals['_STREAMORDERSRESPONSE']._serialized_end=11533
  _globals['_TRADESREQUEST']._serialized_start=11536
  _globals['_TRADESREQUEST']._serialized_end=12020
  _globals['_TRADESRESPONSE']._serialized_start=12023
  _globals['_TRADESRESPONSE']._serialized_end=12182
  _globals['_DERIVATIVETRADE']._serialized_start=12185
  _globals['_DERIVATIVETRADE']._serialized_end=12691
  _globals['_POSITIONDELTA']._serialized_start=12694
  _globals['_POSITIONDELTA']._serialized_end=12881
  _globals['_TRADESV2REQUEST']._serialized_start=12884
  _globals['_TRADESV2REQUEST']._serialized_end=13370
  _globals['_TRADESV2RESPONSE']._serialized_start=13373
  _globals['_TRADESV2RESPONSE']._serialized_end=13534
  _globals['_STREAMTRADESREQUEST']._serialized_start=13537
  _globals['_STREAMTRADESREQUEST']._serialized_end=14027
  _globals['_STREAMTRADESRESPONSE']._serialized_start=14030
  _globals['_STREAMTRADESRESPONSE']._serialized_end=14195
  _globals['_STREAMTRADESV2REQUEST']._serialized_start=14198
  _globals['_STREAMTRADESV2REQUEST']._serialized_end=14690
  _globals['_STREAMTRADESV2RESPONSE']._serialized_start=14693
  _globals['_STREAMTRADESV2RESPONSE']._serialized_end=14860
  _globals['_SUBACCOUNTORDERSLISTREQUEST']._serialized_start=14863
  _globals['_SUBACCOUNTORDERSLISTREQUEST']._serialized_end=15000
  _globals['_SUBACCOUNTORDERSLISTRESPONSE']._serialized_start=15003
  _globals['_SUBACCOUNTORDERSLISTRESPONSE']._serialized_end=15181
  _globals['_SUBACCOUNTTRADESLISTREQUEST']._serialized_start=15184
  _globals['_SUBACCOUNTTRADESLISTREQUEST']._serialized_end=15390
  _globals['_SUBACCOUNTTRADESLISTRESPONSE']._serialized_start=15392
  _globals['_SUBACCOUNTTRADESLISTRESPONSE']._serialized_end=15498
  _globals['_ORDERSHISTORYREQUEST']._serialized_start=15501
  _globals['_ORDERSHISTORYREQUEST']._serialized_end=16009
  _globals['_ORDERSHISTORYRESPONSE']._serialized_start=16012
  _globals['_ORDERSHISTORYRESPONSE']._serialized_end=16185
  _globals['_DERIVATIVEORDERHISTORY']._serialized_start=16188
  _globals['_DERIVATIVEORDERHISTORY']._serialized_end=16869
  _globals['_STREAMORDERSHISTORYREQUEST']._serialized_start=16872
  _globals['_STREAMORDERSHISTORYREQUEST']._serialized_end=17092
  _globals['_STREAMORDERSHISTORYRESPONSE']._serialized_start=17095
  _globals['_STREAMORDERSHISTORYRESPONSE']._serialized_end=17274
  _globals['_OPENINTERESTREQUEST']._serialized_start=17276
  _globals['_OPENINTERESTREQUEST']._serialized_end=17329
  _globals['_OPENINTERESTRESPONSE']._serialized_start=17331
  _globals['_OPENINTERESTRESPONSE']._serialized_end=17447
  _globals['_MARKETOPENINTEREST']._serialized_start=17449
  _globals['_MARKETOPENINTEREST']._serialized_end=17535
  _globals['_INJECTIVEDERIVATIVEEXCHANGERPC']._serialized_start=17538
  _globals['_INJECTIVEDERIVATIVEEXCHANGERPC']._serialized_end=21210
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.ibc.applications.transfer.v1 import (
    query_pb2 as ibc_transfer_query,
    query_pb2_grpc as ibc_transfer_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IBCTransferGrpcApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = ibc_transfer_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_params(self) -> Dict[str, Any]:
        request = ibc_transfer_query.QueryParamsRequest()
        response = await self._execute_call(call=self._stub.Params, request=request)

        return response

    async def fetch_denom_trace(self, hash: str) -> Dict[str, Any]:
        request = ibc_transfer_query.QueryDenomTraceRequest(hash=hash)
        response = await self._execute_call(call=self._stub.DenomTrace, request=request)

        return response

    async def fetch_denom_traces(self, pagination: Optional[PaginationOption] = None) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_transfer_query.QueryDenomTracesRequest(pagination=pagination.create_pagination_request())
        response = await self._execute_call(call=self._stub.DenomTraces, request=request)

        return response

    async def fetch_denom_hash(self, trace: str) -> Dict[str, Any]:
        request = ibc_transfer_query.QueryDenomHashRequest(trace=trace)
        response = await self._execute_call(call=self._stub.DenomHash, request=request)

        return response

    async def fetch_escrow_address(self, port_id: str, channel_id: str) -> Dict[str, Any]:
        request = ibc_transfer_query.QueryEscrowAddressRequest(port_id=port_id, channel_id=channel_id)
        response = await self._execute_call(call=self._stub.EscrowAddress, request=request)

        return response

    async def fetch_total_escrow_for_denom(self, denom: str) -> Dict[str, Any]:
        request = ibc_transfer_query.QueryTotalEscrowForDenomRequest(denom=denom)
        response = await self._execute_call(call=self._stub.TotalEscrowForDenom, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



import datetime
from abc import ABC, abstractmethod
from http.cookies import SimpleCookie
from typing import List, Optional

import grpc
from grpc import ChannelCredentials
from grpc.aio import Call, Metadata


class CookieAssistant(ABC):
    @abstractmethod
    def cookie(self) -> Optional[str]:
        ...

    @abstractmethod
    async def process_response_metadata(self, grpc_call: Call):
        ...

    def metadata(self) -> Metadata:
        cookie = self.cookie()
        metadata = Metadata()
        if cookie is not None and cookie != "":
            metadata.add("cookie", cookie)
        return metadata


class BareMetalLoadBalancedCookieAssistant(CookieAssistant):
    def __init__(self):
        self._cookie: Optional[str] = None

    def cookie(self) -> Optional[str]:
        self._check_cookie_expiration()

        return self._cookie

    async def process_response_metadata(self, grpc_call: Call):
        metadata = await grpc_call.initial_metadata()
        if "set-cookie" in metadata:
            self._cookie = metadata["set-cookie"]

    def _check_cookie_expiration(self):
        if self._is_cookie_expired(cookie_data=self._cookie):
            self._cookie = None

    def _is_cookie_expired(self, cookie_data: str) -> bool:
        # The cookies for these nodes do not expire
        return False


class ExpiringCookieAssistant(CookieAssistant):
    def __init__(self, expiration_time_keys_sequence: List[str], time_format: str):
        self._cookie: Optional[str] = None
        self._expiration_time_keys_sequence = expiration_time_keys_sequence
        self._time_format = time_format

    @classmethod
    def for_kubernetes_public_server(cls):
        return cls(
            expiration_time_keys_sequence=["grpc-cookie", "expires"],
            time_format="%a, %d-%b-%Y %H:%M:%S %Z",
        )

    def cookie(self) -> Optional[str]:
        self._check_cookie_expiration()

        return self._cookie

    async def process_response_metadata(self, grpc_call: Call):
        metadata = await grpc_call.initial_metadata()
        if "set-cookie" in metadata:
            self._cookie = metadata["set-cookie"]

    def _check_cookie_expiration(self):
        if self._is_cookie_expired():
            self._cookie = None

    def _is_cookie_expired(self) -> bool:
        is_expired = False

        if self._cookie is not None:
            cookie = SimpleCookie()
            cookie.load(self._cookie)
            cookie_map = cookie

            for key in self._expiration_time_keys_sequence[:-1]:
                cookie_map = cookie.get(key, {})

            expiration_data: Optional[str] = cookie_map.get(self._expiration_time_keys_sequence[-1], None)
            if expiration_data is not None:
                expiration_time = datetime.datetime.strptime(expiration_data, self._time_format)
                is_expired = datetime.datetime.utcnow() >= expiration_time

        return is_expired


class DisabledCookieAssistant(CookieAssistant):
    def cookie(self) -> Optional[str]:
        return None

    async def process_response_metadata(self, grpc_call: Call):
        pass


class Network:
    def __init__(
        self,
        lcd_endpoint: str,
        tm_websocket_endpoint: str,
        grpc_endpoint: str,
        grpc_exchange_endpoint: str,
        grpc_explorer_endpoint: str,
        chain_stream_endpoint: str,
        chain_id: str,
        fee_denom: str,
        env: str,
        chain_cookie_assistant: CookieAssistant,
        exchange_cookie_assistant: CookieAssistant,
        explorer_cookie_assistant: CookieAssistant,
        official_tokens_list_url: str,
        grpc_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_exchange_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_explorer_channel_credentials: Optional[ChannelCredentials] = None,
        chain_stream_channel_credentials: Optional[ChannelCredentials] = None,
    ):
        self.lcd_endpoint = lcd_endpoint
        self.tm_websocket_endpoint = tm_websocket_endpoint
        self.grpc_endpoint = grpc_endpoint
        self.grpc_exchange_endpoint = grpc_exchange_endpoint
        self.grpc_explorer_endpoint = grpc_explorer_endpoint
        self.chain_stream_endpoint = chain_stream_endpoint
        self.chain_id = chain_id
        self.fee_denom = fee_denom
        self.env = env
        self.chain_cookie_assistant = chain_cookie_assistant
        self.exchange_cookie_assistant = exchange_cookie_assistant
        self.explorer_cookie_assistant = explorer_cookie_assistant
        self.official_tokens_list_url = official_tokens_list_url
        self.grpc_channel_credentials = grpc_channel_credentials
        self.grpc_exchange_channel_credentials = grpc_exchange_channel_credentials
        self.grpc_explorer_channel_credentials = grpc_explorer_channel_credentials
        self.chain_stream_channel_credentials = chain_stream_channel_credentials

    @classmethod
    def devnet(cls):
        return cls(
            lcd_endpoint="https://devnet.lcd.injective.dev",
            tm_websocket_endpoint="wss://devnet.tm.injective.dev/websocket",
            grpc_endpoint="devnet.injective.dev:9900",
            grpc_exchange_endpoint="devnet.injective.dev:9910",
            grpc_explorer_endpoint="devnet.injective.dev:9911",
            chain_stream_endpoint="devnet.injective.dev:9999",
            chain_id="injective-777",
            fee_denom="inj",
            env="devnet",
            chain_cookie_assistant=DisabledCookieAssistant(),
            exchange_cookie_assistant=DisabledCookieAssistant(),
            explorer_cookie_assistant=DisabledCookieAssistant(),
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/devnet.json",
        )

    @classmethod
    def testnet(cls, node="lb"):
        nodes = [
            "lb",
            "sentry",
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        grpc_channel_credentials = grpc.ssl_channel_credentials()
        grpc_exchange_channel_credentials = grpc.ssl_channel_credentials()
        grpc_explorer_channel_credentials = grpc.ssl_channel_credentials()
        chain_stream_channel_credentials = grpc.ssl_channel_credentials()

        if node == "lb":
            lcd_endpoint = "https://testnet.sentry.lcd.injective.network:443"
            tm_websocket_endpoint = "wss://testnet.sentry.tm.injective.network:443/websocket"
            grpc_endpoint = "testnet.sentry.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "testnet.sentry.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "testnet.sentry.explorer.grpc.injective.network:443"
            chain_stream_endpoint = "testnet.sentry.chain.stream.injective.network:443"
            chain_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
            exchange_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
            explorer_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        else:
            lcd_endpoint = "https://testnet.lcd.injective.network:443"
            tm_websocket_endpoint = "wss://testnet.tm.injective.network:443/websocket"
            grpc_endpoint = "testnet.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "testnet.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "testnet.explorer.grpc.injective.network:443"
            chain_stream_endpoint = "testnet.chain.stream.injective.network:443"
            chain_cookie_assistant = DisabledCookieAssistant()
            exchange_cookie_assistant = DisabledCookieAssistant()
            explorer_cookie_assistant = DisabledCookieAssistant()

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-888",
            fee_denom="inj",
            env="testnet",
            chain_cookie_assistant=chain_cookie_assistant,
            exchange_cookie_assistant=exchange_cookie_assistant,
            explorer_cookie_assistant=explorer_cookie_assistant,
            grpc_channel_credentials=grpc_channel_credentials,
            grpc_exchange_channel_credentials=grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=chain_stream_channel_credentials,
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/testnet.json",
        )

    @classmethod
    def mainnet(cls, node="lb"):
        nodes = [
            "lb",
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        lcd_endpoint = "https://sentry.lcd.injective.network:443"
        tm_websocket_endpoint = "wss://sentry.tm.injective.network:443/websocket"
        grpc_endpoint = "sentry.chain.grpc.injective.network:443"
        grpc_exchange_endpoint = "sentry.exchange.grpc.injective.network:443"
        grpc_explorer_endpoint = "sentry.explorer.grpc.injective.network:443"
        chain_stream_endpoint = "sentry.chain.stream.injective.network:443"
        chain_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        exchange_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        explorer_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        grpc_channel_credentials = grpc.ssl_channel_credentials()
        grpc_exchange_channel_credentials = grpc.ssl_channel_credentials()
        grpc_explorer_channel_credentials = grpc.ssl_channel_credentials()
        chain_stream_channel_credentials = grpc.ssl_channel_credentials()

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-1",
            fee_denom="inj",
            env="mainnet",
            chain_cookie_assistant=chain_cookie_assistant,
            exchange_cookie_assistant=exchange_cookie_assistant,
            explorer_cookie_assistant=explorer_cookie_assistant,
            grpc_channel_credentials=grpc_channel_credentials,
            grpc_exchange_channel_credentials=grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=chain_stream_channel_credentials,
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/mainnet.json",
        )

    @classmethod
    def local(cls):
        return cls(
            lcd_endpoint="http://localhost:10337",
            tm_websocket_endpoint="ws://localhost:26657/websocket",
            grpc_endpoint="localhost:9900",
            grpc_exchange_endpoint="localhost:9910",
            grpc_explorer_endpoint="localhost:9911",
            chain_stream_endpoint="localhost:9999",
            chain_id="injective-1",
            fee_denom="inj",
            env="local",
            chain_cookie_assistant=DisabledCookieAssistant(),
            exchange_cookie_assistant=DisabledCookieAssistant(),
            explorer_cookie_assistant=DisabledCookieAssistant(),
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/mainnet.json",
        )

    @classmethod
    def custom(
        cls,
        lcd_endpoint,
        tm_websocket_endpoint,
        grpc_endpoint,
        grpc_exchange_endpoint,
        grpc_explorer_endpoint,
        chain_stream_endpoint,
        chain_id,
        env,
        official_tokens_list_url: str,
        chain_cookie_assistant: Optional[CookieAssistant] = None,
        exchange_cookie_assistant: Optional[CookieAssistant] = None,
        explorer_cookie_assistant: Optional[CookieAssistant] = None,
        grpc_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_exchange_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_explorer_channel_credentials: Optional[ChannelCredentials] = None,
        chain_stream_channel_credentials: Optional[ChannelCredentials] = None,
    ):
        chain_assistant = chain_cookie_assistant or DisabledCookieAssistant()
        exchange_assistant = exchange_cookie_assistant or DisabledCookieAssistant()
        explorer_assistant = explorer_cookie_assistant or DisabledCookieAssistant()
        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id=chain_id,
            fee_denom="inj",
            env=env,
            chain_cookie_assistant=chain_assistant,
            exchange_cookie_assistant=exchange_assistant,
            explorer_cookie_assistant=explorer_assistant,
            official_tokens_list_url=official_tokens_list_url,
            grpc_channel_credentials=grpc_channel_credentials,
            grpc_exchange_channel_credentials=grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=chain_stream_channel_credentials,
        )

    @classmethod
    def custom_chain_and_public_indexer_mainnet(
        cls,
        lcd_endpoint,
        tm_websocket_endpoint,
        grpc_endpoint,
        chain_stream_endpoint,
        chain_cookie_assistant: Optional[CookieAssistant] = None,
    ):
        mainnet_network = cls.mainnet()

        return cls.custom(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=mainnet_network.grpc_exchange_endpoint,
            grpc_explorer_endpoint=mainnet_network.grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-1",
            env="mainnet",
            chain_cookie_assistant=chain_cookie_assistant or DisabledCookieAssistant(),
            exchange_cookie_assistant=mainnet_network.exchange_cookie_assistant,
            explorer_cookie_assistant=mainnet_network.explorer_cookie_assistant,
            official_tokens_list_url=mainnet_network.official_tokens_list_url,
            grpc_channel_credentials=None,
            grpc_exchange_channel_credentials=mainnet_network.grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=mainnet_network.grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=None,
        )

    def string(self):
        return self.env

    def create_chain_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.grpc_endpoint, self.grpc_channel_credentials)

    def create_exchange_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.grpc_exchange_endpoint, self.grpc_exchange_channel_credentials)

    def create_explorer_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.grpc_explorer_endpoint, self.grpc_explorer_channel_credentials)

    def create_chain_stream_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.chain_stream_endpoint, self.chain_stream_channel_credentials)

    def _create_grpc_channel(self, endpoint: str, credentials: Optional[ChannelCredentials]) -> grpc.Channel:
        if credentials is None:
            channel = grpc.aio.insecure_channel(endpoint)
        else:
            channel = grpc.aio.secure_channel(endpoint, credentials)
        return channel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/consensus/module/v1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/consensus/module/v1/module.proto\x12\x1a\x63osmos.consensus.module.v1\x1a cosmos/app/v1alpha1/module.proto\"X\n\x06Module\x12\x1c\n\tauthority\x18\x01 \x01(\tR\tauthority:0\xba\xc0\x96\xda\x01*\n(github.com/cosmos/cosmos-sdk/x/consensusB\xb8\x01\n\x1e\x63om.cosmos.consensus.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43\x43M\xaa\x02\x1a\x43osmos.Consensus.Module.V1\xca\x02\x1a\x43osmos\\Consensus\\Module\\V1\xe2\x02&Cosmos\\Consensus\\Module\\V1\\GPBMetadata\xea\x02\x1d\x43osmos::Consensus::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.consensus.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.cosmos.consensus.module.v1B\013ModuleProtoP\001\242\002\003CCM\252\002\032Cosmos.Consensus.Module.V1\312\002\032Cosmos\\Consensus\\Module\\V1\342\002&Cosmos\\Consensus\\Module\\V1\\GPBMetadata\352\002\035Cosmos::Consensus::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001*\n(github.com/cosmos/cosmos-sdk/x/consensus'
  _globals['_MODULE']._serialized_start=105
  _globals['_MODULE']._serialized_end=193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/syntax.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%google/api/expr/v1alpha1/syntax.proto\x12\x18google.api.expr.v1alpha1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x01\n\nParsedExpr\x12\x32\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x04\x65xpr\x12\x45\n\x0bsource_info\x18\x03 \x01(\x0b\x32$.google.api.expr.v1alpha1.SourceInfoR\nsourceInfo\"\xcb\r\n\x04\x45xpr\x12\x0e\n\x02id\x18\x02 \x01(\x03R\x02id\x12\x43\n\nconst_expr\x18\x03 \x01(\x0b\x32\".google.api.expr.v1alpha1.ConstantH\x00R\tconstExpr\x12\x45\n\nident_expr\x18\x04 \x01(\x0b\x32$.google.api.expr.v1alpha1.Expr.IdentH\x00R\tidentExpr\x12H\n\x0bselect_expr\x18\x05 \x01(\x0b\x32%.google.api.expr.v1alpha1.Expr.SelectH\x00R\nselectExpr\x12\x42\n\tcall_expr\x18\x06 \x01(\x0b\x32#.google.api.expr.v1alpha1.Expr.CallH\x00R\x08\x63\x61llExpr\x12H\n\tlist_expr\x18\x07 \x01(\x0b\x32).google.api.expr.v1alpha1.Expr.CreateListH\x00R\x08listExpr\x12N\n\x0bstruct_expr\x18\x08 \x01(\x0b\x32+.google.api.expr.v1alpha1.Expr.CreateStructH\x00R\nstructExpr\x12]\n\x12\x63omprehension_expr\x18\t \x01(\x0b\x32,.google.api.expr.v1alpha1.Expr.ComprehensionH\x00R\x11\x63omprehensionExpr\x1a\x1b\n\x05Ident\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1au\n\x06Select\x12\x38\n\x07operand\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x07operand\x12\x14\n\x05\x66ield\x18\x02 \x01(\tR\x05\x66ield\x12\x1b\n\ttest_only\x18\x03 \x01(\x08R\x08testOnly\x1a\x8e\x01\n\x04\x43\x61ll\x12\x36\n\x06target\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x06target\x12\x1a\n\x08\x66unction\x18\x02 \x01(\tR\x08\x66unction\x12\x32\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x04\x61rgs\x1as\n\nCreateList\x12:\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x08\x65lements\x12)\n\x10optional_indices\x18\x02 \x03(\x05R\x0foptionalIndices\x1a\xdb\x02\n\x0c\x43reateStruct\x12!\n\x0cmessage_name\x18\x01 \x01(\tR\x0bmessageName\x12K\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x31.google.api.expr.v1alpha1.Expr.CreateStruct.EntryR\x07\x65ntries\x1a\xda\x01\n\x05\x45ntry\x12\x0e\n\x02id\x18\x01 \x01(\x03R\x02id\x12\x1d\n\tfield_key\x18\x02 \x01(\tH\x00R\x08\x66ieldKey\x12\x39\n\x07map_key\x18\x03 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00R\x06mapKey\x12\x34\n\x05value\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x05value\x12%\n\x0eoptional_entry\x18\x05 \x01(\x08R\roptionalEntryB\n\n\x08key_kind\x1a\x9a\x03\n\rComprehension\x12\x19\n\x08iter_var\x18\x01 \x01(\tR\x07iterVar\x12\x1b\n\titer_var2\x18\x08 \x01(\tR\x08iterVar2\x12=\n\niter_range\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\titerRange\x12\x19\n\x08\x61\x63\x63u_var\x18\x03 \x01(\tR\x07\x61\x63\x63uVar\x12;\n\taccu_init\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x08\x61\x63\x63uInit\x12\x45\n\x0eloop_condition\x18\x05 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\rloopCondition\x12;\n\tloop_step\x18\x06 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x08loopStep\x12\x36\n\x06result\x18\x07 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x06resultB\x0b\n\texpr_kind\"\xc1\x03\n\x08\x43onstant\x12;\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00R\tnullValue\x12\x1f\n\nbool_value\x18\x02 \x01(\x08H\x00R\tboolValue\x12!\n\x0bint64_value\x18\x03 \x01(\x03H\x00R\nint64Value\x12#\n\x0cuint64_value\x18\x04 \x01(\x04H\x00R\x0buint64Value\x12#\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00R\x0b\x64oubleValue\x12#\n\x0cstring_value\x18\x06 \x01(\tH\x00R\x0bstringValue\x12!\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00R\nbytesValue\x12\x46\n\x0e\x64uration_value\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01H\x00R\rdurationValue\x12I\n\x0ftimestamp_value\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01H\x00R\x0etimestampValueB\x0f\n\rconstant_kind\"\x8c\x07\n\nSourceInfo\x12%\n\x0esyntax_version\x18\x01 \x01(\tR\rsyntaxVersion\x12\x1a\n\x08location\x18\x02 \x01(\tR\x08location\x12!\n\x0cline_offsets\x18\x03 \x03(\x05R\x0blineOffsets\x12Q\n\tpositions\x18\x04 \x03(\x0b\x32\x33.google.api.expr.v1alpha1.SourceInfo.PositionsEntryR\tpositions\x12U\n\x0bmacro_calls\x18\x05 \x03(\x0b\x32\x34.google.api.expr.v1alpha1.SourceInfo.MacroCallsEntryR\nmacroCalls\x12N\n\nextensions\x18\x06 \x03(\x0b\x32..google.api.expr.v1alpha1.SourceInfo.ExtensionR\nextensions\x1a\x80\x03\n\tExtension\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12i\n\x13\x61\x66\x66\x65\x63ted_components\x18\x02 \x03(\x0e\x32\x38.google.api.expr.v1alpha1.SourceInfo.Extension.ComponentR\x12\x61\x66\x66\x65\x63tedComponents\x12P\n\x07version\x18\x03 \x01(\x0b\x32\x36.google.api.expr.v1alpha1.SourceInfo.Extension.VersionR\x07version\x1a\x35\n\x07Version\x12\x14\n\x05major\x18\x01 \x01(\x03R\x05major\x12\x14\n\x05minor\x18\x02 \x01(\x03R\x05minor\"o\n\tComponent\x12\x19\n\x15\x43OMPONENT_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OMPONENT_PARSER\x10\x01\x12\x1a\n\x16\x43OMPONENT_TYPE_CHECKER\x10\x02\x12\x15\n\x11\x43OMPONENT_RUNTIME\x10\x03\x1a<\n\x0ePositionsEntry\x12\x10\n\x03key\x18\x01 \x01(\x03R\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\x1a]\n\x0fMacroCallsEntry\x12\x10\n\x03key\x18\x01 \x01(\x03R\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x05value:\x02\x38\x01\"p\n\x0eSourcePosition\x12\x1a\n\x08location\x18\x01 \x01(\tR\x08location\x12\x16\n\x06offset\x18\x02 \x01(\x05R\x06offset\x12\x12\n\x04line\x18\x03 \x01(\x05R\x04line\x12\x16\n\x06\x63olumn\x18\x04 \x01(\x05R\x06\x63olumnB\xef\x01\n\x1c\x63om.google.api.expr.v1alpha1B\x0bSyntaxProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x18Google.Api.Expr.V1alpha1\xca\x02\x18Google\\Api\\Expr\\V1alpha1\xe2\x02$Google\\Api\\Expr\\V1alpha1\\GPBMetadata\xea\x02\x1bGoogle::Api::Expr::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.syntax_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\013SyntaxProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001\242\002\003GAE\252\002\030Google.Api.Expr.V1alpha1\312\002\030Google\\Api\\Expr\\V1alpha1\342\002$Google\\Api\\Expr\\V1alpha1\\GPBMetadata\352\002\033Google::Api::Expr::V1alpha1'
  _globals['_CONSTANT'].fields_by_name['duration_value']._loaded_options = None
  _globals['_CONSTANT'].fields_by_name['duration_value']._serialized_options = b'\030\001'
  _globals['_CONSTANT'].fields_by_name['timestamp_value']._loaded_options = None
  _globals['_CONSTANT'].fields_by_name['timestamp_value']._serialized_options = b'\030\001'
  _globals['_SOURCEINFO_POSITIONSENTRY']._loaded_options = None
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_options = b'8\001'
  _globals['_SOURCEINFO_MACROCALLSENTRY']._loaded_options = None
  _globals['_SOURCEINFO_MACROCALLSENTRY']._serialized_options = b'8\001'
  _globals['_PARSEDEXPR']._serialized_start=163
  _globals['_PARSEDEXPR']._serialized_end=298
  _globals['_EXPR']._serialized_start=301
  _globals['_EXPR']._serialized_end=2040
  _globals['_EXPR_IDENT']._serialized_start=856
  _globals['_EXPR_IDENT']._serialized_end=883
  _globals['_EXPR_SELECT']._serialized_start=885
  _globals['_EXPR_SELECT']._serialized_end=1002
  _globals['_EXPR_CALL']._serialized_start=1005
  _globals['_EXPR_CALL']._serialized_end=1147
  _globals['_EXPR_CREATELIST']._serialized_start=1149
  _globals['_EXPR_CREATELIST']._serialized_end=1264
  _globals['_EXPR_CREATESTRUCT']._serialized_start=1267
  _globals['_EXPR_CREATESTRUCT']._serialized_end=1614
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_start=1396
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_end=1614
  _globals['_EXPR_COMPREHENSION']._serialized_start=1617
  _globals['_EXPR_COMPREHENSION']._serialized_end=2027
  _globals['_CONSTANT']._serialized_start=2043
  _globals['_CONSTANT']._serialized_end=2492
  _globals['_SOURCEINFO']._serialized_start=2495
  _globals['_SOURCEINFO']._serialized_end=3403
  _globals['_SOURCEINFO_EXTENSION']._serialized_start=2862
  _globals['_SOURCEINFO_EXTENSION']._serialized_end=3246
  _globals['_SOURCEINFO_EXTENSION_VERSION']._serialized_start=3080
  _globals['_SOURCEINFO_EXTENSION_VERSION']._serialized_end=3133
  _globals['_SOURCEINFO_EXTENSION_COMPONENT']._serialized_start=3135
  _globals['_SOURCEINFO_EXTENSION_COMPONENT']._serialized_end=3246
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_start=3248
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_end=3308
  _globals['_SOURCEINFO_MACROCALLSENTRY']._serialized_start=3310
  _globals['_SOURCEINFO_MACROCALLSENTRY']._serialized_end=3403
  _globals['_SOURCEPOSITION']._serialized_start=3405
  _globals['_SOURCEPOSITION']._serialized_end=3517
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.auction.v1beta1 import query_pb2 as injective_dot_auction_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AuctionParams = channel.unary_unary(
                '/injective.auction.v1beta1.Query/AuctionParams',
                request_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryAuctionParamsRequest.SerializeToString,
                response_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryAuctionParamsResponse.FromString,
                _registered_method=True)
        self.CurrentAuctionBasket = channel.unary_unary(
                '/injective.auction.v1beta1.Query/CurrentAuctionBasket',
                request_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryCurrentAuctionBasketRequest.SerializeToString,
                response_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryCurrentAuctionBasketResponse.FromString,
                _registered_method=True)
        self.AuctionModuleState = channel.unary_unary(
                '/injective.auction.v1beta1.Query/AuctionModuleState',
                request_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
                response_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
                _registered_method=True)
        self.LastAuctionResult = channel.unary_unary(
                '/injective.auction.v1beta1.Query/LastAuctionResult',
                request_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryLastAuctionResultRequest.SerializeToString,
                response_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryLastAuctionResultResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def AuctionParams(self, request, context):
        """Retrieves auction params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CurrentAuctionBasket(self, request, context):
        """Retrieves current auction basket with current highest bid and bidder
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuctionModuleState(self, request, context):
        """Retrieves the entire auction module's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastAuctionResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AuctionParams': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionParams,
                    request_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryAuctionParamsRequest.FromString,
                    response_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryAuctionParamsResponse.SerializeToString,
            ),
            'CurrentAuctionBasket': grpc.unary_unary_rpc_method_handler(
                    servicer.CurrentAuctionBasket,
                    request_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryCurrentAuctionBasketRequest.FromString,
                    response_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryCurrentAuctionBasketResponse.SerializeToString,
            ),
            'AuctionModuleState': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionModuleState,
                    request_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.FromString,
                    response_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.SerializeToString,
            ),
            'LastAuctionResult': grpc.unary_unary_rpc_method_handler(
                    servicer.LastAuctionResult,
                    request_deserializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryLastAuctionResultRequest.FromString,
                    response_serializer=injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryLastAuctionResultResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.auction.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.auction.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def AuctionParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.auction.v1beta1.Query/AuctionParams',
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryAuctionParamsRequest.SerializeToString,
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryAuctionParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CurrentAuctionBasket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.auction.v1beta1.Query/CurrentAuctionBasket',
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryCurrentAuctionBasketRequest.SerializeToString,
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryCurrentAuctionBasketResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AuctionModuleState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.auction.v1beta1.Query/AuctionModuleState',
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LastAuctionResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.auction.v1beta1.Query/LastAuctionResult',
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryLastAuctionResultRequest.SerializeToString,
            injective_dot_auction_dot_v1beta1_dot_query__pb2.QueryLastAuctionResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
